@@ -2,17 +2,12 @@ import requests
 import logging
 
 
-
-
-
-
-
-
 class LOGIN:
     def __init__(self):
         ...
 
-    def zhogntai(self,username,password):
+    @classmethod
+    def zhogntai(cls,username,password):
         for _ in range(3):
             try:
                 headers = {
