@@ -3,28 +3,20 @@
 # @Time    : 1992
 # @Project : chpypi
 # @Software: PyCharm
-import getproxies
-import login
+from chpypi import getproxies
+from chpypi import login
 
 
-
-
-
-
-
-
-
-
-
-
-class HTTPTOOLS():
+class HTTPTOOLS:
     def __init__(self):
         ...
 
-    def login_chen_hai(self):
+    @classmethod
+    def login_chen_hai(cls):
         return login.LOGIN
 
-    def get_proxies(self):
+    @classmethod
+    def get_proxies(cls):
         return getproxies.PROXIES
 
 
